import requests
from ScraGet.Exceptions import UserNotFound
headers = {"user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.101 Safari/537.36"}
#"https://scratch.mit.edu/discuss/topic/96414/?page=11#post-1624859"
#"https://scratchdb.lefty.one/v3/docs/"
class get_user:
  def __init__(self):
    pass
  
  def updateScratchDB(self,user):
    info = requests.get(f"https://scratchdb.lefty.one/v3/user/info/{user}")
    self.response_time = info.elapsed.total_seconds()
    self.status_code = info.status_code
    if self.status_code == 200:
      info = info.json()
      self.username = info["username"]
      self.id = info["id"]
      self.pfp = f"https://cdn2.scratch.mit.edu/get_image/user/{self.id}_90x90.png?v="
      self.sys_id = info["sys_id"]
      self.join_date = info["joined"]
      self.country = info["country"]
      self.AboutMe = info["bio"]
      self.wiwo = info["work"]
      self.status = info["status"]
      self.school = info["school"]
      self.country_rank = info["statistics"]["ranks"]["country"]
      del info["statistics"]["ranks"]["country"]
      self.rank = info["statistics"]["ranks"]
      del info["statistics"]["ranks"]
      self.stats = info["statistics"]
    
    elif self.status_code == 404:
      raise Exceptions.UserNotFound("User '{user}' not found.")

  def updateScratch(self,user):
    info = requests.get(f"https://api.scratch.mit.edu/users/{user}",headers = headers)
    self.response_time = info.elapsed.total_seconds()
    self.status_code = info.status_code
    if self.status_code == 200:
      info = info.json()
      self.username = info["username"]
      self.id = info["id"]
      self.join_date = info["history"]["joined"]
      self.scratchteam = info["scratchteam"]
      self.profile_stats = info["profile"]
      self.profile_id = info["profile"]["id"]
      self.pfp = info["profile"]["images"]["90x90"]
      self.country = info["profile"]["country"]
      self.AboutMe = info["profile"]["bio"]
      self.wiwo = info["profile"]["status"]
    
    elif self.status_code == 404:
      raise UserNotFound(f"User '{user}' not found.")

class get_user_extra:
  def __init__(self):
    pass
  
  def updateScratch(self,user):
    
    info = requests.get(f"https://api.scratch.mit.edu/users/{user}/messages/count",headers=headers)
    self.messages_response_time = info.elapsed.total_seconds()
    self.messages_status_code = info.status_code
    
    if self.messages_status_code == 200:
      info = info.json()
      self.messages = info["count"]
      
    elif self.messages_status_code == 404:
      raise UserNotFound(f"User '{user}' not found.")

    info = requests.get(f"https://scratch.mit.edu/site-api/users/all/{user}",headers=headers)    
    self.profile_status_code = info.status_code
    self.profile_response_time = info.elapsed.total_seconds()
    
    if self.profile_status_code == 200:
      info = info.json()
      self.label_name = info["featured_project_label_name"]
      self.featured_project_data = info["featured_project_data"]
      self.featured_project_id = info["featured_project"]
      self.creator_id = info["user"]["pk"]
      self.user = info["user"]["username"]
      
      if self.featured_project_data != None:
        self.creator = self.featured_project_data["creator"]
        self.change_time = self.featured_project_data["datetime_modified"]
        self.title = self.featured_project_data["title"]
        self.featured_project_label_id = info["featured_project_label_id"]
        self.thumbnail = f"https://cdn2.scratch.mit.edu/get_image/project/{self.featured_project_id}_480x360.png"
      else:
        self.creator = None
        self.change_time = None
        self.featured_project_label_id = None
        self.title = None
        self.thumbnail = None
  
      self.pfp = f"https://cdn2.scratch.mit.edu/get_image/user/{self.creator_id}_90x90.png?v="
      self.id = info["id"] #WAT IS THIS


import requests
from ScraGet.Exceptions import PageNotFound

headers = {"user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.101 Safari/537.36"}

class get_frontpage:
  def __init__(self):
    pass
  
  def updateScratch(self):
    info = requests.get(f"https://api.scratch.mit.edu/proxy/featured",headers=headers)
    self.response_time = info.elapsed.total_seconds()
    self.status_code = info.status_code
    
    if self.status_code == 200:
      info = info.json()
      self.new_projects = info["community_newest_projects"]
      self.top_remixed = info["community_most_remixed_projects"]
      self.design_studio = info["scratch_design_studio"]
      self.curated_projects = info["curator_top_projects"]
      self.featured_studios = info["community_featured_studios"]
      self.top_loved = info["community_most_loved_projects"]
      self.featured_projects = info["community_featured_projects"]
      
    elif self.status_code == 404:
      raise PageNotFound("There was a 404 error in API...")


import requests
from ScraGet.Exceptions import PostNotFound, TopicNotFound

class get_post:
  def __init__(self):
    pass
  
  def updateScratchDB(self,ID):
    info = requests.get(f"https://scratchdb.lefty.one/v3/forum/post/info/{ID}")
    self.response_time = info.elapsed.total_seconds()
    self.status_code = info.status_code
    
    if self.status_code == 200:
      info = info.json()
      self.id = info["id"]
      self.username = info["username"]
      self.deleted = info["deleted"]
      self.editor = info["editor"]
      self.posted = info["time"]["posted"]
      self.last_edited = info["time"]["edited"]
      self.contentHTML = info["content"]["html"]
      self.contentBB = info["content"]["bb"]
      self.topic_id = info["topic"]["id"]
      topic = get_topic()
      topic.updateScratchDB(self.topic_id)
      if topic.status_code == 200:
        self.title = topic.title
        self.category = topic.category
        self.closed = topic.closed
        self.deleted = topic.deleted
        self.topic_posts = topic.post_count
      else:
        self.title = info["topic"]["title"]
        self.category = info["topic"]["category"]
        self.closed = info["topic"]["closed"]
        self.deleted = info["topic"]["deleted"]
    
    elif self.status_code == 404:
      raise PostNotFound(f"Post with id '{str(ID)}' not found.")

class get_topic:
  def __init__(self):
    pass
  
  def updateScratchDB(self,ID):
    info = requests.get(f"https://scratchdb.lefty.one/v3/forum/topic/info/{ID}")
    self.response_time = info.elapsed.total_seconds()
    self.status_code = info.status_code
    
    if self.status_code == 200:
      info = info.json()
      self.id = info["id"]
      self.title = info["title"]
      self.category = info["category"]
      self.closed = info["closed"]
      self.deleted = info["deleted"]
      self.post_count = info["post_count"]
    
    elif self.status_code == 404:
      raise TopicNotFound(f"Topic with id '{str(ID)}' not found.")


class UserNotFound(Exception):
  pass

class ProjectNotFound(Exception):
  pass

class StudioNotFound(Exception):
  pass

class PostNotFound(Exception):
  pass

class TopicNotFound(Exception):
  pass

class PageNotFound(Exception):
  pass



from ScraGet.forum import get_post, get_topic
from ScraGet.project import get_project
from ScraGet.studios import get_studio
from ScraGet.user import get_user, get_user_extra
from ScraGet.frontpage import get_frontpage

#this is a file to make using this package easier.


import requests
from ScraGet.Exceptions import ProjectNotFound

headers = {"user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.101 Safari/537.36"}

class get_project:
  def __init__(self):
    pass
  
  def updateScratchDB(self,ID):
    info = requests.get(f"https://scratchdb.lefty.one/v3/project/info/{ID}")
    self.response_time = info.elapsed.total_seconds()
    self.status_code = info.status_code
    
    if self.status_code == 200:
      info = info.json()
      self.id = info["id"]
      self.thumbnail = f"https://cdn2.scratch.mit.edu/get_image/project/{self.id}_480x360.png"
      self.title  = info["title"]
      self.description = info["description"]
      self.instructions = info["instructions"]
      #self.visibility = info["visibility"]
      self.public = info["public"]
      self.commenting = info["comments_allowed"]
      #self.published = info["is_published"]
      self.author = info["username"]
      #self.thumbnail = info["image"]
      #self.images = info["images"]
      self.created = info["times"]["created"]
      self.last_modified = info["times"]["modified"]
      self.shared = info["times"]["shared"]
      self.ranks = info["statistics"]["ranks"]
      del info["statistics"]["ranks"]
      self.stats = info["statistics"]
      self.remix = info["remix"]
      self.metadata = info["metadata"]
    
    elif self.status_code == 404:
      raise ProjectNotFound(f"Project with id '{str(ID)}' not found.")
    
  def updateScratch(self, ID):
    info = requests.get(f"https://api.scratch.mit.edu/projects/{ID}",headers=headers)
    self.response_time = info.elapsed.total_seconds()
    self.status_code = info.status_code
    
    if self.status_code == 200:
      info = info.json()
      self.id = info["id"]
      self.title  = info["title"]
      self.description = info["description"]
      self.instructions = info["instructions"]
      self.visibility = info["visibility"]
      self.public = info["public"]
      self.commenting = info["comments_allowed"]
      self.published = info["is_published"]
      self.author = info["author"]
      self.thumbnail = info["image"]
      self.images = info["images"]
      self.created = info["history"]["created"]
      self.last_modified = info["history"]["modified"]
      self.shared = info["history"]["shared"]
      self.stats = info["stats"]
      self.remix = info["remix"]
    
    elif self.status_code == 404:
      raise ProjectNotFound(f"Project with id '{str(ID)}' not found.")




import requests
from ScraGet.Exceptions import StudioNotFound

headers = {"user-agent": "Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/91.0.4472.101 Safari/537.36"}

class get_studio:
  def __init__(self):
    pass
  
  def updateScratchDB(self,ID):
    info = requests.get(f"https://api.scratch.mit.edu/studios/{ID}",headers=headers)
    self.response_time = info.elapsed.total_seconds()
    self.status_code = info.status_code
    
    if self.status_code == 200:
      info = info.json()
      self.id = info["id"]
      self.title = info["title"]
      self.owner = info["owner"]
      self.description = info["description"]
      self.visibility = info["visibility"]
      self.public = info["public"]
      self.open = info["open_to_all"]
      self.com_allow = info["comments_allowed"]
      self.image = info["image"]
      self.created = info["history"]["created"]
      self.modified = info["history"]["modified"]
      self.history = info["history"]
      self.stats = info["stats"]
    
    elif self.status_code == 404:
      raise StudioNotFound(f"Studio with id '{str(ID)}' not found.")


#uploaded this as... it was difficult for me to make. so now others can copy this format (and hopefully credit me)
import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ScraGet",
    version="0.1.1",
    #author="QuantumCodes",
    #author_email="author@example.com",
    description="A package that makes interacting with Scratch API easier",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/Quantum-Codes/ScraGet",
    license='MIT',#added
    packages=['ScraGet'],#added
    project_urls={
        "Bug Tracker": "https://github.com/Quantum-Codes/ScraGet/issues",
        "Documentation": "https://github.com/Quantum-Codes/ScraGet/wiki"
    },
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.6',
)